==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/benefit/DetailContent.java <==
package com.thebeastshop.support.vo.benefit;

import java.io.Serializable;
import java.util.List;

/**
 * Created by feilong.gao on 2017/4/18.
 */
public class DetailContent implements Serializable {
    private static final long serialVersionUID = -4223262918226829742L;

    /**
     * 链接
     */
    private String link;

    /**
     * link类型
     */
    private String linkType;

    /**
     * 链接跳转推荐文案
     */
    private String btnText;
    /**
     * 项目内容：“积分奖励：+100积分”
     */
    private List<String> contents;

    /**
     * 项目描述:"等级礼包自会有升级7天后发放，当前等级有效期内均可领取"
     */
    private List<String> desc;

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getLinkType() {
        return linkType;
    }

    public void setLinkType(String linkType) {
        this.linkType = linkType;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public List<String> getContents() {
        return contents;
    }

    public void setContents(List<String> contents) {
        this.contents = contents;
    }

    public List<String> getDesc() {
        return desc;
    }

    public void setDesc(List<String> desc) {
        this.desc = desc;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("DetailContent{");
        sb.append("link='").append(link).append('\'');
        sb.append(", linkType='").append(linkType).append('\'');
        sb.append(", btnText='").append(btnText).append('\'');
        sb.append(", contents=").append(contents);
        sb.append(", desc=").append(desc);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.6.13-sources.jar: com/thebeastshop/support/vo/benefit/DetailContent.java <==
package com.thebeastshop.support.vo.benefit;

import java.io.Serializable;
import java.util.List;

/**
 * Created by feilong.gao on 2017/4/18.
 */
public class DetailContent implements Serializable {
    private static final long serialVersionUID = -4223262918226829742L;

    /**
     * 链接
     */
    private String link;

    /**
     * 小程序链接
     */
    private String mpLink;

    /**
     * link类型
     */
    private String linkType;

    /**
     * 链接跳转推荐文案
     */
    private String btnText;
    /**
     * 项目内容：“积分奖励：+100积分”
     */
    private List<String> contents;

    /**
     * 项目描述:"等级礼包自会有升级7天后发放，当前等级有效期内均可领取"
     */
    private List<String> desc;

    /**
     * 生日到店礼，线下门店跳转链接配置
     */
    private List<Object> giftContents;

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getMpLink() {
        return mpLink;
    }

    public void setMpLink(String mpLink) {
        this.mpLink = mpLink;
    }

    public String getLinkType() {
        return linkType;
    }

    public void setLinkType(String linkType) {
        this.linkType = linkType;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public List<String> getContents() {
        return contents;
    }

    public void setContents(List<String> contents) {
        this.contents = contents;
    }

    public List<String> getDesc() {
        return desc;
    }

    public void setDesc(List<String> desc) {
        this.desc = desc;
    }


    public List<Object> getGiftContents() {
        return giftContents;
    }

    public void setGiftContents(List<Object> giftContents) {
        this.giftContents = giftContents;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("DetailContent{");
        sb.append("link='").append(link).append('\'');
        sb.append(", linkType='").append(linkType).append('\'');
        sb.append(", btnText='").append(btnText).append('\'');
        sb.append(", contents=").append(contents);
        sb.append(", desc=").append(desc);
        sb.append(", giftContents=").append(giftContents);
        sb.append('}');
        return sb.toString();
    }
}
